@@ -1,3 +1,4 @@
+import logging
 from pathlib import Path
 
 import django
@@ -8,6 +9,8 @@ from django.views.generic import TemplateView
 
 from django_weasyprint import WeasyTemplateResponseMixin, WeasyTemplateView
 
+logging.basicConfig(level=logging.DEBUG)
+
 
 class BaseView(TemplateView):
     # simple Django CBV with template
